@@ -40,10 +40,10 @@ class PagedFilteredTableView(SingleTableView):
         selection, see filters.py.
         """
         qs = super().get_queryset().order_by('source_language', 'source_text')
-        if len(self.session.subset) == 1:
+        if self.session.subset is not None and len(self.session.subset) == 1:
             qs = qs.filter(source_text__istartswith=self.session.subset)
         self.filter = self.filter_class(self.request.GET, queryset=qs)
-        self.filter.form.helper = self.formhelper_class(user=self.request.user)
+        self.filter.form.helper = self.formhelper_class(user=self.request.user, subset=self.session.subset)
         return self.filter.qs
 
     def __init__(self, *args, **kwargs):
@@ -79,6 +79,7 @@ class PagedFilteredTableView(SingleTableView):
         context['practice'] = PracticeTable(
             data=Word.objects.filter(id__in=self.session.practice_list).order_by("source_text"))
         context[self.context_filter_name] = self.filter
+        context['subset'] = self.session.subset
         return context
 
     def get(self, request: WSGIRequest, *args, **kwargs) -> HttpResponse:
@@ -103,8 +104,10 @@ class PagedFilteredTableView(SingleTableView):
         self.session.practice_list = list(Practice.objects.filter(
             ip=self.ip).values_list(
             "word_id", flat=True).order_by("word__source_text"))
-        logger.debug(self.session)
-        if any([let in request.GET for let in 'abcdefghijklmnopqrstuvwxyz']):
+        logger.debug(f"{request.GET=}")
+        if 'source_text__icontains' in request.GET and request.GET['source_text__icontains']:
+            self.session.subset = None
+        elif any([let in request.GET for let in 'abcdefghijklmnopqrstuvwxyz']):
             for let in request.GET:
                 if len(let) == 1:  # really pressed a letter button?
                     logger.info(f"set subset selection to {let}")
@@ -157,7 +160,7 @@ class WordTableView(PagedFilteredTableView):
     table_class = WordTable
     practice_table_class = PracticeTable
     template_name = 'elo/word.html'
-    paginate_by = 50
+    paginate_by = 10
     filter_class = WordFilter
     formhelper_class = WordFilterFormHelper
 
